@@ -196,6 +196,15 @@ class Shell():
         self._header_bottom = ht
         self.mt_width = self._header_right + 49
 
+    def clear(self):
+        """
+        Remove all scrollback text from the window
+        """
+        backbuffer = list(self.backbuffer)
+        printstring = "\n"
+        for i in range(self.height):
+            self.put(printstring)
+
     def _print_backbuffer(self):
         """
         Print the previously printed output above the current command line.
@@ -206,16 +215,15 @@ class Shell():
         """
         rev = list(self.backbuffer)
         rev.reverse()
-        i = 0
 
-        for string, iscommand in rev:
+        for i, tup in zip(range(len(rev)), rev):
+            string, iscommand = tup
             ypos = self.height-2-i
             if ypos > 0:
                 printstring = string
                 if iscommand:
                     printstring = "%s%s" % (self.prompt, string)
                 self.stdscr.addstr(ypos,0,printstring)
-            i += 1
 
     def _print_help(self):
         """
@@ -504,8 +512,11 @@ class Shell():
                     if ret_choice == constants.CHOICE_INVALID:
                         self.put("Invalid command")
                     else:
-                        if command.new_menu and ret_choice != constants.FAILURE:
+                        menus = [a.name for a in self.menus]
+                        if (command.new_menu and ret_choice != constants.FAILURE):
                             self.menu = command.new_menu
+                        elif str(ret_choice).lower() in menus:
+                            self.menu = ret_choice.lower()
             except Exception as e:
                 self.put(e)
         return self
